@@ -1,9 +1,7 @@
-from typing import Dict, Any, AsyncIterable, Callable, Set
+from typing import Dict, Any, AsyncIterable
 import logging
 import tiktoken
-from rich.console import Console
-
-console = Console()
+import re
 
 logger = logging.getLogger(__name__)
 
@@ -75,3 +73,8 @@ def truncate_to_tokens(text: str, max_tokens: int, encoding_name: str = "cl100k_
     encoding = tiktoken.get_encoding(encoding_name)
     tokens = encoding.encode(text)[:max_tokens]
     return encoding.decode(tokens)
+
+def strip_ansi(text):
+    """Remove ANSI escape sequences from text."""
+    ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
+    return ansi_escape.sub('', text)
